﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Encodings.PackingEncoding.MultiComponentVector {
  [Item("SingleItemRotationMoveAttribute", "Specifies the tabu attributes for a single item rotation move on an multi component vector.")]
  [StorableClass]
  public class SingleItemRotationMoveAttribute : MultiComponentVectorMoveAttribute {
    [Storable]
    public int AffectedGroup { get; protected set; }
    [Storable]
    public int Index { get; protected set; }
    [Storable]
    public int ItemIndex { get; protected set; }
    [Storable]
    public bool ItemRotation { get; protected set; }

    [StorableConstructor]
    protected SingleItemRotationMoveAttribute(bool deserializing) : base(deserializing) { }
    protected SingleItemRotationMoveAttribute(SingleItemRotationMoveAttribute original, Cloner cloner)
      : base(original, cloner) {
      this.AffectedGroup = original.AffectedGroup;
      this.Index = original.Index;
      this.ItemIndex = original.ItemIndex;
      this.ItemRotation = original.ItemRotation;
    }
    public SingleItemRotationMoveAttribute() : this(-1, -1, -1, false, -1) { }
    public SingleItemRotationMoveAttribute(int affectedGroup, int index, int itemIndex, bool itemRotation, double moveQuality)
      : base(moveQuality) {
        AffectedGroup = affectedGroup;
        Index = index;
      ItemIndex = itemIndex;
      ItemRotation = itemRotation;
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new SingleItemRotationMoveAttribute(this, cloner);
    }
  }
}
